package net.sf.doolin.gui.action;

import net.sf.doolin.gui.expression.GUIExpression;
import net.sf.doolin.gui.util.GUIStrings;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.BeanNameAware;

/**
 * This class provides support for the text and the icon.
 * 
 * @author Damien Coraboeuf
 */
public abstract class AbstractSimpleGUIAction extends AbstractGUIAction
		implements BeanNameAware {

	private String id;

	private String title;
	private String tip;
	private String shortcut;
	private String iconId;

	/**
	 * Gets the icon id.
	 * 
	 * @return the icon id
	 */
	public String getIconId() {
		return this.iconId;
	}

	@Override
	public GUIExpression getIconIDExpression(ActionContext context) {
		init();
		GUIExpression expression = new GUIExpression(context
				.getSubscriberValidator(), context.getData(), this.iconId);
		return expression;
	}

	@Override
	public String getId() {
		return this.id;
	}

	/**
	 * Gets the shortcut.
	 * 
	 * @return the shortcut
	 */
	public String getShortcut() {
		return this.shortcut;
	}

	/**
	 * {@inheritDoc}.
	 * 
	 * @param context
	 *            the context
	 * 
	 * @return the shortcut model
	 */
	@Override
	public GUIExpression getShortcutExpression(ActionContext context) {
		init();
		GUIExpression expression = new GUIExpression(context
				.getSubscriberValidator(), context.getData(), this.shortcut);
		return expression;
	}

	/**
	 * {@inheritDoc}.
	 * 
	 * @param context
	 *            the context
	 * 
	 * @return the text model
	 */
	@Override
	public GUIExpression getTextExpression(ActionContext context) {
		init();
		GUIExpression expression = new GUIExpression(context
				.getSubscriberValidator(), context.getData(), this.title);
		return expression;
	}

	/**
	 * Gets the tip.
	 * 
	 * @return the tip
	 */
	public String getTip() {
		return this.tip;
	}

	/**
	 * {@inheritDoc}.
	 * 
	 * @param context
	 *            the context
	 * 
	 * @return the tip model
	 */
	@Override
	public GUIExpression getTipExpression(ActionContext context) {
		init();
		GUIExpression expression = new GUIExpression(context
				.getSubscriberValidator(), context.getData(), this.tip);
		return expression;
	}

	/**
	 * Gets the title.
	 * 
	 * @return the title
	 */
	public String getTitle() {
		return this.title;
	}

	/**
	 * Lazy initialisation of attributes.
	 */
	public void init() {
		if (StringUtils.isNotBlank(this.id)) {
			// Title
			if (StringUtils.isBlank(this.title)) {
				String titleKey = this.id;
				if (GUIStrings.isDefined(titleKey)) {
					this.title = GUIStrings.get(titleKey);
				}
			}
			// Tip
			if (StringUtils.isBlank(this.tip)) {
				String tipKey = this.id + ".tip";
				if (GUIStrings.isDefined(tipKey)) {
					this.tip = GUIStrings.get(tipKey);
				}
			}
			// Shortcut
			if (StringUtils.isBlank(this.shortcut)) {
				String shortcutKey = this.id + ".key";
				if (GUIStrings.isDefined(shortcutKey)) {
					this.shortcut = GUIStrings.get(shortcutKey);
				}
			}
			// Icon id
			if (StringUtils.isBlank(this.iconId)) {
				String iconKey = this.id + ".icon";
				if (GUIStrings.isDefined(iconKey)) {
					this.iconId = GUIStrings.get(iconKey);
				}
			}
		}
	}

	/**
	 * {@inheritDoc}.
	 * 
	 * @param name
	 *            the name
	 */
	@Override
	public void setBeanName(String name) {
		this.id = name;
	}

	/**
	 * Sets the icon id.
	 * 
	 * @param iconId
	 *            the new icon id
	 */
	public void setIconId(String iconId) {
		this.iconId = iconId;
	}

	/**
	 * Sets the shortcut.
	 * 
	 * @param shortcut
	 *            the new shortcut
	 */
	public void setShortcut(String shortcut) {
		this.shortcut = shortcut;
	}

	/**
	 * Sets the tip.
	 * 
	 * @param tip
	 *            the new tip
	 */
	public void setTip(String tip) {
		this.tip = tip;
	}

	/**
	 * Sets the title.
	 * 
	 * @param title
	 *            the new title
	 */
	public void setTitle(String title) {
		this.title = title;
	}

	/**
	 * String representation (id).
	 */
	@Override
	public String toString() {
		return this.id;
	}

}
