package net.sf.doolin.gui.action;

import net.sf.doolin.gui.action.support.ActionDelegate;

import org.springframework.beans.factory.annotation.Required;

/**
 * Dialog action that delegates to another object after the dialog has been
 * validated.
 * 
 * @author Damien Coraboeuf (x74639)
 * 
 * @param <T>
 *            Type of data
 */
public class DelegateDialogAction<T> extends DialogAction<T> {

	private ActionDelegate<T> delegate;

	@Override
	protected void onOK(ActionContext actionContext, T bean) {
		this.delegate.call(actionContext, bean);
	}

	/**
	 * Gets the delegate.
	 * 
	 * @return the delegate
	 */
	public ActionDelegate<T> getDelegate() {
		return this.delegate;
	}

	/**
	 * Sets the delegate.
	 * 
	 * @param delegate
	 *            the new delegate
	 */
	@Required
	public void setDelegate(ActionDelegate<T> delegate) {
		this.delegate = delegate;
	}

}
