package net.sf.doolin.gui.action;

import net.sf.doolin.gui.action.task.GUITask;
import net.sf.doolin.gui.action.task.GUITaskExecutor;

import org.springframework.beans.factory.annotation.Required;

/**
 * This action executes a {@link GUITask} after a dialog has been displayed and
 * validated.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <T>
 *            Type of the input to the task
 * @param <R>
 *            Type of the return from the task
 */
public class TaskDialogAction<T, R> extends DialogAction<T> {

	private GUITaskExecutor<T, R> taskExecutor;
	private GUITask<T, R> task;

	/**
	 * Gets the task to executed
	 * 
	 * @return Task to execute
	 */
	public GUITask<T, R> getTask() {
		return this.task;
	}

	/**
	 * Gets the task executor
	 * 
	 * @return Task executor
	 */
	public GUITaskExecutor<T, R> getTaskExecutor() {
		return this.taskExecutor;
	}

	/**
	 * Executes the task
	 * 
	 * @see GUITaskExecutor#execute(ActionContext, Object, GUITask)
	 */
	@Override
	protected void onOK(ActionContext actionContext, T bean) throws Exception {
		this.taskExecutor.execute(actionContext, bean, this.task);
	}

	/**
	 * Sets the task to execute
	 * 
	 * @param task
	 *            Task to execute
	 */
	@Required
	public void setTask(GUITask<T, R> task) {
		this.task = task;
	}

	/**
	 * Sets the task executor
	 * 
	 * @param taskExecutor
	 *            Task executor
	 */
	@Required
	public void setTaskExecutor(GUITaskExecutor<T, R> taskExecutor) {
		this.taskExecutor = taskExecutor;
	}

}
