package net.sf.doolin.gui.action.path.item;

import java.util.Stack;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.action.swing.ActionFactory;
import net.sf.doolin.gui.action.swing.MenuBuilder;

/**
 * Defines a way to install an <i>action</i> in a {@link MenuBuilder} for a
 * given {@link ActionContext}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public interface ActionPath {

	/**
	 * Returns a stack of sub-paths where to install the action. This stack can
	 * be used directly by the called of its method. An empty stack means that
	 * the action is installed at the <i>root</i> of the menu builder. Any stack
	 * element forces the menu builder to create sub menu builders.
	 * 
	 * @return A stack of path.
	 * @see MenuBuilder
	 */
	Stack<String> getPathStack();

	/**
	 * Defines an identifier for this action path when it is used as a
	 * replacement for another action path.
	 * 
	 * @return Identifier
	 */
	String getSource();

	/**
	 * Defines an identifier when this action path is defined as a placeholder
	 * for other action path(s).
	 * 
	 * @return Identifier or <code>null</code>
	 */
	String getTarget();

	/**
	 * Installs this action path in a menu builder for a given action context.
	 * 
	 * @param menuBuilder
	 *            Menu builder
	 * @param actionFactory
	 *            Action factory to use
	 * @param actionContext
	 *            Action context to use
	 */
	void install(MenuBuilder menuBuilder, ActionFactory actionFactory,
			ActionContext actionContext);

}
