package net.sf.doolin.gui.action.path.item;

import java.util.List;

import javax.swing.Action;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.action.GUIAction;
import net.sf.doolin.gui.action.swing.ActionFactory;
import net.sf.doolin.gui.action.swing.MenuBuilder;
import net.sf.doolin.gui.service.IconSize;

/**
 * This action path defines the replacement of a placeholder by another action.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ReplacementActionPath extends AbstractActionPath {

	private final GUIAction action;

	private final String placeholder;

	/**
	 * Constructor with no path
	 * 
	 * @param action
	 *            Action to set
	 * @param placeholder
	 *            Placeholder to replace
	 */
	public ReplacementActionPath(GUIAction action, String placeholder) {
		super();
		this.action = action;
		this.placeholder = placeholder;
	}

	/**
	 * Constructor with some paths
	 * 
	 * @param action
	 *            Action to set
	 * @param placeholder
	 *            Placeholder to replace
	 * @param paths
	 *            List of paths
	 */
	public ReplacementActionPath(GUIAction action, String placeholder,
			List<String> paths) {
		super(paths);
		this.action = action;
		this.placeholder = placeholder;
	}

	/**
	 * Gets the action to set
	 * 
	 * @return Action
	 */
	public GUIAction getAction() {
		return this.action;
	}

	/**
	 * Gets the placeholder to replace
	 * 
	 * @return Placeholder name
	 */
	public String getPlaceholder() {
		return this.placeholder;
	}

	/**
	 * Returns the placeholder complete identifier
	 */
	@Override
	public String getSource() {
		return getPathID() + ";@" + this.placeholder;
	}

	@Override
	public void install(MenuBuilder menuBuilder, ActionFactory actionFactory,
			ActionContext actionContext) {
		// Creates the Swing action
		Action swingAction = actionFactory.createAction(actionContext,
				this.action, IconSize.SMALL);
		// Adds to the menu builder at the place holder level
		menuBuilder.add(actionContext.getSubscriberValidator(), swingAction);
	}

	@Override
	public String toString() {
		return super.toString() + ">" + this.action.getId() + "@"
				+ this.placeholder;
	}

}
