package net.sf.doolin.gui.action.path.toolbar;

import java.awt.BorderLayout;

import javax.swing.SwingConstants;

/**
 * Specification for the position of a tool bar in its hosting component.
 * 
 * @author Damien Coraboeuf
 * 
 */
public enum BarPosition {

	/**
	 * At the top
	 */
	TOP(BorderLayout.NORTH, SwingConstants.HORIZONTAL),

	/**
	 * At the bottom
	 */
	BOTTOM(BorderLayout.SOUTH, SwingConstants.HORIZONTAL),

	/**
	 * At the left
	 */
	LEFT(BorderLayout.WEST, SwingConstants.VERTICAL),

	/**
	 * At the right
	 */
	RIGHT(BorderLayout.EAST, SwingConstants.VERTICAL);

	private final Object borderConstraint;
	private final int orientation;

	private BarPosition(Object borderConstraint, int orientation) {
		this.borderConstraint = borderConstraint;
		this.orientation = orientation;
	}

	/**
	 * Gets the constraint for a {@link BorderLayout}.
	 * 
	 * @return Constraint
	 */
	public Object getBorderConstraint() {
		return this.borderConstraint;
	}

	/**
	 * Orientation of the tool bar, as defined in
	 * {@link javax.swing.JToolBar#setOrientation(int)}.
	 * 
	 * @return Orientation
	 */
	public int getOrientation() {
		return this.orientation;
	}

}
