package net.sf.doolin.gui.action.support;

import net.sf.doolin.bus.bean.Bean;
import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.validation.ValidationSupport;
import net.sf.doolin.gui.validation.support.ValidationSupportImpl;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Provides support for the context object.
 * 
 * @author Damien Coraboeuf
 * 
 */
public abstract class AbstractActionContext extends Bean
		implements
			ActionContext {

	private static final long serialVersionUID = 1L;

	private static final Logger log = LoggerFactory
			.getLogger(AbstractActionContext.class);

	private Object context;
	private ValidationSupport<?> validationSupport;

	/**
	 * Constructor with a <code>null</code> context.
	 */
	public AbstractActionContext() {
	}

	/**
	 * Constructor with an initial context.
	 * 
	 * @param aContext
	 *            Initial context
	 */
	public AbstractActionContext(Object aContext) {
		this.context = aContext;
	}

	/**
	 * Creates the validation support
	 * 
	 * @param <T>
	 *            Type of bean for the validator
	 * @return Validation support for this action context
	 */
	@SuppressWarnings("unchecked")
	protected <T> ValidationSupport<T> createValidationSupport() {
		return new ValidationSupportImpl<T>((T) getData(),
				getSubscriberValidator());
	}

	/**
	 * Returns the context.
	 * 
	 * {@inheritDoc}
	 */
	@Override
	public Object getContext() {
		return this.context;
	}

	@SuppressWarnings("unchecked")
	@Override
	public synchronized ValidationSupport<?> getValidationSupport() {
		if (this.validationSupport == null) {
			this.validationSupport = createValidationSupport();
		}
		return this.validationSupport;
	}

	/**
	 * Sets the context
	 * 
	 * @param value
	 *            New context value
	 */
	@Override
	public void setContext(Object value) {
		Object old = this.context;
		if (log.isDebugEnabled()) {
			log.debug(String.format(
					"Context value has been changed to %s for %s", value,
					getClass().getName()));
		}
		this.context = value;
		notify("context", old, value);
	}

}
