package net.sf.doolin.gui.action.support;

import javax.swing.JComponent;

import net.sf.doolin.bus.support.SubscriberValidator;
import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.app.GUIApplication;
import net.sf.doolin.gui.validation.ValidationSupport;
import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.window.GUIWindow;

/**
 * This action context wraps another action context but provides its own data.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class DelegateDataActionContext implements ActionContext {

	private final ActionContext delegate;
	private final Object data;

	/**
	 * Constructor
	 * 
	 * @param delegate
	 *            Delegate action context
	 * @param data
	 *            Data to provide
	 */
	public DelegateDataActionContext(ActionContext delegate, Object data) {
		this.delegate = delegate;
		this.data = data;
	}

	public GUIApplication getApplication() {
		return this.delegate.getApplication();
	}

	public JComponent getComponent() {
		return this.delegate.getComponent();
	}

	public Object getContext() {
		return this.delegate.getContext();
	}

	@Override
	public Object getData() {
		return this.data;
	}

	public SubscriberValidator getSubscriberValidator() {
		return this.delegate.getSubscriberValidator();
	}

	public <V> ValidationSupport<V> getValidationSupport() {
		return this.delegate.getValidationSupport();
	}

	public <T> GUIView<T> getView() {
		return this.delegate.getView();
	}

	public <T> GUIWindow<T> getWindow() {
		return this.delegate.getWindow();
	}

	public void setContext(Object value) {
		this.delegate.setContext(value);
	}

}
