package net.sf.doolin.gui.action.swing;

import java.awt.Component;

import javax.swing.Action;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;

import net.sf.doolin.bus.support.SubscriberValidator;

import org.apache.commons.lang.StringUtils;

/**
 * Pop-up menu builder
 * 
 * @author Damien Coraboeuf
 * 
 */
public class JPopupMenuBuilder extends AbstractJMenuBuilder {

	private final JPopupMenu popupMenu;

	/**
	 * Constructor.
	 * 
	 * @param popupMenu
	 *            Pop-up menu to build.
	 */
	public JPopupMenuBuilder(JPopupMenu popupMenu) {
		this.popupMenu = popupMenu;
	}

	@Override
	public void add(SubscriberValidator subscriberValidator, Action swingAction) {
		noSeparator();
		JMenuItem menuItem = createMenuItem(subscriberValidator, swingAction);
		this.popupMenu.add(menuItem);
	}

	@Override
	public MenuBuilder createSubMenu(String name, String label) {
		JMenu subMenu = getMenuByName(name);
		if (subMenu != null) {
			return (JMenuBuilder) subMenu.getClientProperty(JMenuBuilder.class);
		} else {
			subMenu = createMenu(name, label);
			this.popupMenu.add(subMenu);
			noSeparator();
			JMenuBuilder menuContainer = new JMenuBuilder(subMenu);
			subMenu.putClientProperty(JMenuBuilder.class, menuContainer);
			return menuContainer;
		}
	}

	@Override
	public void clear() {
		this.popupMenu.removeAll();
	}

	/**
	 * Utility method that looks for a sub-menu using the
	 * {@link JMenu#getName() name} of the menu as an identifier.
	 * 
	 * @param name
	 *            Name to find
	 * @return Found {@link JMenu} or <code>null</code>
	 */
	protected JMenu getMenuByName(String name) {
		int count = this.popupMenu.getComponentCount();
		for (int i = 0; i < count; i++) {
			Component component = this.popupMenu.getComponent(i);
			if (component instanceof JMenu
					&& StringUtils.equals(name, component.getName())) {
				return (JMenu) component;
			}
		}
		return null;
	}

	@Override
	protected void createSeparator() {
		this.popupMenu.addSeparator();
	}

}
