package net.sf.doolin.gui.display;

/**
 * State adapter based on a condition
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ConditionalStateAdapter extends AbstractStateAdapter<Object> {

	private ConditionalOperator operator = ConditionalOperator.NOT_NULL;
	private Object operand;
	private DisplayState ifTrueState = DisplayState.ENABLED;
	private DisplayState ifFalseState = DisplayState.DISABLED;

	@Override
	public DisplayState convertSubjectToTarget(Object subjectValue) {
		// Evaluates the operator
		boolean result = this.operator.evaluate(subjectValue, this.operand);
		// Result
		if (result) {
			return this.ifTrueState;
		} else {
			return this.ifFalseState;
		}
	}

	/**
	 * Gets the if false state.
	 * 
	 * @return the if false state
	 */
	public DisplayState getIfFalseState() {
		return this.ifFalseState;
	}

	/**
	 * Gets the if true state.
	 * 
	 * @return the if true state
	 */
	public DisplayState getIfTrueState() {
		return this.ifTrueState;
	}

	/**
	 * Gets the operand.
	 * 
	 * @return the operand
	 */
	public Object getOperand() {
		return this.operand;
	}

	/**
	 * Gets the operator.
	 * 
	 * @return the operator
	 */
	public ConditionalOperator getOperator() {
		return this.operator;
	}

	/**
	 * Display state to return when condition is evaluated to <code>false</code>
	 * 
	 * @param ifFalseState
	 *            Display state to return when condition is evaluated to true
	 */
	public void setIfFalseState(DisplayState ifFalseState) {
		this.ifFalseState = ifFalseState;
	}

	/**
	 * Display state to return when condition is evaluated to <code>true</code>
	 * 
	 * @param ifTrueState
	 *            Display state to return when condition is evaluated to true
	 */
	public void setIfTrueState(DisplayState ifTrueState) {
		this.ifTrueState = ifTrueState;
	}

	/**
	 * Sets the operand for the operator.
	 * 
	 * @param operand
	 *            the new operand
	 */
	public void setOperand(Object operand) {
		this.operand = operand;
	}

	/**
	 * Sets the operator to use.
	 * 
	 * @param operator
	 *            the new operator
	 */
	public void setOperator(ConditionalOperator operator) {
		this.operator = operator;
	}

}
