package net.sf.doolin.gui.display;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import net.sf.doolin.gui.action.ActionContext;

import org.springframework.beans.factory.annotation.Required;

/**
 * Display state handler that operates an operation between several handlers.
 * 
 * @author Damien Coraboeuf
 * 
 */
public abstract class MultiDisplayStateHandler extends
		AbstractDisplayStateHandler {

	private List<DisplayStateHandler> handlers = new ArrayList<DisplayStateHandler>();

	/**
	 * Default constructor
	 */
	public MultiDisplayStateHandler() {
	}

	/**
	 * Constructor from an array
	 * 
	 * @param handlers
	 *            Array of handlers
	 */
	public MultiDisplayStateHandler(DisplayStateHandler... handlers) {
		this.handlers = Arrays.asList(handlers);
	}

	/**
	 * Constructor from a list.
	 * 
	 * @param handlers
	 *            List of handlers
	 */
	public MultiDisplayStateHandler(List<DisplayStateHandler> handlers) {
		this.handlers = handlers;
	}

	/**
	 * Gets the handlers.
	 * 
	 * @return the handlers
	 */
	public List<DisplayStateHandler> getHandlers() {
		return this.handlers;
	}

	/**
	 * Utility method to add one {@link DisplayStateHandler} to the list.
	 * 
	 * @param handler
	 *            {@link DisplayStateHandler} to add
	 */
	public void setDisplayStateHandler(DisplayStateHandler handler) {
		this.handlers.add(handler);
	}

	/**
	 * Sets the handlers.
	 * 
	 * @param handlers
	 *            the new handlers
	 */
	@Required
	public void setHandlers(List<DisplayStateHandler> handlers) {
		this.handlers = handlers;
	}

	@Override
	public void subscribe(ActionContext actionContext, Runnable task) {
		for (DisplayStateHandler handler : this.handlers) {
			handler.subscribe(actionContext, task);
		}
	}

}
