package net.sf.doolin.gui.edit;

import net.sf.doolin.bus.bean.Bean;
import net.sf.doolin.gui.util.GUIStrings;

/**
 * Abstract ancestor for {@link GUIEdit} implementations, which provides support
 * for the message and for the life-cycle.
 * 
 * @author Damien Coraboeuf
 * 
 */
public abstract class AbstractGUIEdit extends Bean implements GUIEdit {

	private static final long serialVersionUID = 1L;

	private final String msgKey;
	private final Object[] msgParameters;

	private boolean done;

	/**
	 * Constructor.
	 * 
	 * @param msgKey
	 *            Key for the message
	 * @param msgParameters
	 *            Parameters for the message
	 */
	public AbstractGUIEdit(String msgKey, Object... msgParameters) {
		this.msgKey = msgKey;
		this.msgParameters = msgParameters;
	}

	@Override
	public boolean canRedo() {
		return !isDone();
	}

	@Override
	public boolean canUndo() {
		return isDone();
	}

	/**
	 * Runs the main task.
	 */
	protected abstract void doTask();

	@Override
	public String getDisplayName() {
		return GUIStrings.get(this.msgKey, this.msgParameters);
	}

	/**
	 * Checks if the task has been done.
	 * 
	 * @return <code>true</code> if the task has been done.
	 */
	public boolean isDone() {
		return this.done;
	}

	@Override
	public void perform() {
		doTask();
		setDone(true);
	}

	@Override
	public void redo() {
		perform();
	}

	/**
	 * Sets if the task has been done.
	 * 
	 * @param done
	 *            <code>true</code> if the task has been done.
	 */
	protected void setDone(boolean done) {
		notify("done", this.done, this.done = done);
	}

	@Override
	public void undo() {
		undoTask();
		setDone(false);
	}

	/**
	 * Undoes the main task.
	 */
	protected abstract void undoTask();

}
