package net.sf.doolin.gui.edit;

/**
 * Definition of a task that can be done and undone.
 * 
 * @author Damien Coraboeuf
 * 
 */
public interface GUIEdit {

	/**
	 * Undoes this task
	 */
	void undo();

	/**
	 * Redoes this task
	 */
	void redo();

	/**
	 * Performs this task
	 */
	void perform();

	/**
	 * Can this task be undone
	 * 
	 * @return <code>true</code> if this task can be undone
	 */
	boolean canUndo();

	/**
	 * Can this task be done again
	 * 
	 * @return <code>true</code> if this task can be done again
	 */
	boolean canRedo();

	/**
	 * Gets a display name for this task
	 * 
	 * @return Display name
	 */
	String getDisplayName();

}
