package net.sf.doolin.gui.field;

import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.Icon;
import javax.swing.JToggleButton;

import net.sf.doolin.gui.expression.GUIExpression;
import net.sf.doolin.gui.field.support.SimpleField;
import net.sf.doolin.gui.service.IconSize;
import net.sf.doolin.gui.view.GUIView;

/**
 * {@link JToggleButton} field descriptor.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of object for the view
 */
public class FieldToggle<V> extends AbstractPropertyFieldDescriptor<V> {

	private static final long serialVersionUID = 1L;

	private String text = null;
	private String icon = null;
	private String tip = null;

	/**
	 * {@inheritDoc}.
	 * 
	 * @param view
	 *            the view
	 * 
	 * @return the field< v>
	 */
	@Override
	public Field<V> createField(final GUIView<V> view) {

		// Creates the button
		final JToggleButton c = new JToggleButton();
		c.setMargin(new Insets(0, 0, 0, 0));

		// Text expression
		if (this.text != null) {
			GUIExpression textExpression = new GUIExpression(view
					.getActionContext().getSubscriberValidator(), view
					.getViewData(), this.text);
			textExpression.connect(view.getActionContext()
					.getSubscriberValidator(), c, "text");
		}

		// Icon
		if (this.icon != null) {
			// Icon size
			IconSize iconSize = view.getApplication().getParameters().getEnum(
					"FieldToggle.IconSize", IconSize.class, IconSize.SMALL);
			Icon iconObject = getIconService().getIcon(this.icon, iconSize);
			c.setIcon(iconObject);
		}

		// Tip
		if (this.tip != null) {
			GUIExpression tipExpression = new GUIExpression(view
					.getActionContext().getSubscriberValidator(), view
					.getViewData(), this.tip);
			tipExpression.connect(view.getActionContext()
					.getSubscriberValidator(), c, "toolTipText");
		}

		// Component -> Model
		c.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				Object value = c.isSelected();
				setProperty(view, value);
			}
		});

		// Model -> Component
		subscribe(view, c, "selected");

		// OK
		return new SimpleField<V>(view, this, c);
	}

	/**
	 * Gets the icon ID associated with this button
	 * 
	 * @return Icon ID
	 */
	public String getIcon() {
		return this.icon;
	}

	/**
	 * Gets the text.
	 * 
	 * @return the text
	 */
	public String getText() {
		return this.text;
	}

	/**
	 * Gets the tool tip text expression associated with this button.
	 * 
	 * @return Text expression
	 */
	public String getTip() {
		return this.tip;
	}

	/**
	 * Sets the icon ID associated with this button
	 * 
	 * @param icon
	 *            Icon ID
	 */
	public void setIcon(String icon) {
		this.icon = icon;
	}

	/**
	 * Sets the text.
	 * 
	 * @param text
	 *            the new text
	 */
	public void setText(String text) {
		this.text = text;
	}

	/**
	 * Sets the tool tip text expression associated with this button.
	 * 
	 * @param tip
	 *            Text expression
	 */
	public void setTip(String tip) {
		this.tip = tip;
	}

}
