/*
 * Created on 9 avr. 2005
 */
package net.sf.doolin.gui.field.list.multi;

import net.sf.doolin.bus.bean.Bean;

import org.apache.commons.lang.ObjectUtils;

/**
 * Item that can be selected
 * 
 * @author Damien Coraboeuf
 * @param <T>
 *            Type of item
 */
public class SelectableItem<T> extends Bean {

	private static final long serialVersionUID = 1L;

	/**
	 * <code>selected</code> property
	 */
	public static final String SELECTED = "selected";

	/**
	 * Item
	 */
	private final T item;

	/**
	 * State
	 */
	private boolean selected;

	/**
	 * Constructor
	 * 
	 * @param t
	 *            Associated item
	 */
	public SelectableItem(T t) {
		this(t, false);
	}

	/**
	 * Constructor
	 * 
	 * @param t
	 *            Associated item
	 * @param selected
	 *            Initial selection status
	 */
	public SelectableItem(T t, boolean selected) {
		this.item = t;
		this.selected = selected;
	}

	/**
	 * @return Returns the item.
	 */
	public T getItem() {
		return this.item;
	}

	/**
	 * @return Returns the selected.
	 */
	public boolean isSelected() {
		return this.selected;
	}

	/**
	 * @param selected
	 *            The selected to set.
	 */
	public void setSelected(boolean selected) {
		;
		notify(SELECTED, this.selected, this.selected = selected);
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return ObjectUtils.toString(this.item, "");
	}

}
