package net.sf.doolin.gui.field.table.style;

import java.util.List;

import javax.swing.JTable;

import net.sf.doolin.gui.style.ChainedStyle;
import net.sf.doolin.gui.style.Style;

import org.springframework.beans.factory.annotation.Required;

/**
 * Style that relies on a chain of styles which are applied in sequence.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ChainedTableStyle implements TableStyle {

	private List<TableStyle> styles;

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Style getStyle(Object item, JTable table, int row, int column) {
		if (this.styles != null) {
			ChainedStyle styles = new ChainedStyle();
			for (TableStyle style : this.styles) {
				Style theStyle = style.getStyle(item, table, row, column);
				if (theStyle != null) {
					styles.addStyle(theStyle);
				}
			}
			return styles;
		} else {
			return null;
		}
	}

	/**
	 * Gets the styles.
	 * 
	 * @return the styles
	 */
	public List<TableStyle> getStyles() {
		return this.styles;
	}

	/**
	 * Sets the styles.
	 * 
	 * @param styles
	 *            the new styles
	 */
	@Required
	public void setStyles(List<TableStyle> styles) {
		this.styles = styles;
	}

}
