package net.sf.doolin.gui.form;

import java.awt.BorderLayout;
import java.util.ArrayList;
import java.util.List;

import javax.swing.JPanel;

import net.sf.doolin.gui.field.FieldDescriptor;
import net.sf.doolin.gui.layout.FormLayoutService;
import net.sf.doolin.gui.layout.LayoutService;
import net.sf.doolin.gui.validation.DefaultValidationGUIViewDecorator;
import net.sf.doolin.gui.validation.GUIValidationDecorator;
import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.view.descriptor.AbstractGUIViewDescriptor;
import net.sf.doolin.gui.view.support.DefaultGUIView;
import net.sf.doolin.gui.window.GUIWindow;

/**
 * Descriptor for a view that contains a list of fields.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of object for the view
 */
public class FormViewDescriptor<V> extends AbstractGUIViewDescriptor<V> {

	private LayoutService layout = new FormLayoutService("default:grow",
			"default");

	private GUIValidationDecorator validationDecorator = new DefaultValidationGUIViewDecorator();

	private List<FieldDescriptor<V>> fieldList = new ArrayList<FieldDescriptor<V>>(
			0);

	private boolean scrollable;

	/**
	 * Instantiates a new form view descriptor.
	 */
	public FormViewDescriptor() {
		setViewDecorator(this.validationDecorator);
	}

	@Override
	public GUIView<V> createView(GUIWindow<?> parentWindow, V model) {
		// Creates the view
		DefaultGUIView<V> view = new DefaultGUIView<V>(parentWindow, this,
				model, this.scrollable);
		// Initialisation
		initView(view);
		// Gets the form panel
		JPanel viewPanel = view.getViewPanel();
		viewPanel.setLayout(new BorderLayout());
		// Form panel
		FormPanel<V> formPanel = new FormPanel<V>(this.layout,
				this.validationDecorator, this.fieldList);
		viewPanel.add(formPanel, BorderLayout.CENTER);
		// Initialisation
		formPanel.init(view);
		// Adds the form panel to the view
		view.setProperty(FormPanel.class, formPanel);
		// OK
		return view;
	}

	/**
	 * Gets the field list.
	 * 
	 * @return the field list
	 */
	public List<FieldDescriptor<V>> getFieldList() {
		return this.fieldList;
	}

	/**
	 * Gets the layout.
	 * 
	 * @return the layout
	 */
	public LayoutService getLayout() {
		return this.layout;
	}

	/**
	 * Gets the validation decorator.
	 * 
	 * @return the validation decorator
	 */
	public GUIValidationDecorator getValidationDecorator() {
		return this.validationDecorator;
	}

	@Override
	public void initState(GUIView<V> view) {
		// Gets the form panel
		@SuppressWarnings("unchecked")
		FormPanel<V> formPanel = (FormPanel<V>) view
				.getProperty(FormPanel.class);
		// Initialises the state
		formPanel.initState(view);
	}

	/**
	 * Checks if the view content is scrollable
	 * 
	 * @return <code>true</code> if the view content is scrollable
	 */
	public boolean isScrollable() {
		return this.scrollable;
	}

	/**
	 * Sets the field list.
	 * 
	 * @param fieldList
	 *            the new field list
	 */
	public void setFieldList(List<FieldDescriptor<V>> fieldList) {
		this.fieldList = fieldList;
	}

	/**
	 * Sets the layout.
	 * 
	 * @param layout
	 *            the new layout
	 */
	public void setLayout(LayoutService layout) {
		this.layout = layout;
	}

	/**
	 * Sets if the view content is scrollable
	 * 
	 * @param scrollable
	 *            <code>true</code> if the view content is scrollable
	 */
	public void setScrollable(boolean scrollable) {
		this.scrollable = scrollable;
	}

	/**
	 * Sets the validation decorator.
	 * 
	 * @param validationDecorator
	 *            the new validation decorator
	 */
	public void setValidationDecorator(
			GUIValidationDecorator validationDecorator) {
		this.validationDecorator = validationDecorator;
		setViewDecorator(validationDecorator);
	}

}
