package net.sf.doolin.gui.service;

import java.io.File;

/**
 * Interface to the preferences of the application.
 * 
 * @author Damien Coraboeuf
 * 
 */
public interface GUIPreferences {

	/**
	 * Get a preference value as a string
	 * 
	 * @param key
	 *            Preference key
	 * @param defaultValue
	 *            Default value if the key is not defined
	 * @return Preference value
	 */
	String getString(String key, String defaultValue);

	/**
	 * Get a preference value as a boolean
	 * 
	 * @param key
	 *            Preference key
	 * @param defaultValue
	 *            Default value if the key is not defined
	 * @return Preference value
	 */
	Boolean getBoolean(String key, Boolean defaultValue);

	/**
	 * Get a preference value as an integer
	 * 
	 * @param key
	 *            Preference key
	 * @param defaultValue
	 *            Default value if the key is not defined
	 * @return Preference value
	 */
	Integer getInt(String key, Integer defaultValue);

	/**
	 * Sets a preference value as a string
	 * 
	 * @param key
	 *            Preference key
	 * @param value
	 *            Value to store
	 */
	void setString(String key, String value);

	/**
	 * Sets a preference value as a string
	 * 
	 * @param key
	 *            Preference key
	 * @param value
	 *            Value to store
	 */
	void setBoolean(String key, Boolean value);

	/**
	 * Sets a preference value as an integer
	 * 
	 * @param key
	 *            Preference key
	 * @param value
	 *            Value to store
	 */
	void setInt(String key, Integer value);

	/**
	 * Sets a preference value as a long
	 * 
	 * @param key
	 *            Preference key
	 * @param value
	 *            Value to store
	 */
	void setLong(String key, Long value);

	/**
	 * Saves the preferences in the back store
	 */
	void save();

	/**
	 * Gets a preference value as a file.
	 * 
	 * @param key
	 *            Preference key
	 * @return File or <code>null</code> if not found
	 */
	File getFile(String key);

	/**
	 * Sets a preference value as a file.
	 * 
	 * @param key
	 *            Preference key
	 * @param file
	 *            File to store
	 */
	void setFile(String key, File file);

	/**
	 * Saves a <code>{@link Memento}</code> in the preferences.
	 * 
	 * @param memento
	 *            Memento to save
	 */
	void saveMemento(Memento memento);

	/**
	 * Restores a <code>{@link Memento}</code> from the preferences.
	 * 
	 * @param memento
	 *            Memento to restore
	 */
	void restoreMemento(Memento memento);

	/**
	 * Deletes a preference entry.
	 * 
	 * @param key
	 *            Preference entry key
	 */
	void delete(String key);

	/**
	 * Get a preference value as a long
	 * 
	 * @param key
	 *            Preference key
	 * @param defaultValue
	 *            Default value if the key is not defined
	 * @return Preference value
	 */
	Long getLong(String key, Long defaultValue);

}
