package net.sf.doolin.gui.style;

import java.awt.Color;
import java.awt.Component;
import java.awt.Font;
import java.awt.font.TextAttribute;
import java.util.HashMap;
import java.util.Map;

/**
 * Style that updates the font used for the component.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class FontStyle implements Style {

	private boolean strikedThrough;
	private boolean bold;
	private boolean italic;
	private Color fontColor;

	@Override
	public void apply(Component component) {
		// Initial font
		Font font = component.getFont();
		// Attributes for the font
		Map<TextAttribute, Object> attributes = new HashMap<TextAttribute, Object>();
		// Bold
		if (this.bold) {
			attributes.put(TextAttribute.WEIGHT, TextAttribute.WEIGHT_BOLD);
		}
		// Italic
		if (this.italic) {
			attributes
					.put(TextAttribute.POSTURE, TextAttribute.POSTURE_OBLIQUE);
		}
		// Striked through
		if (this.strikedThrough) {
			attributes.put(TextAttribute.STRIKETHROUGH,
					TextAttribute.STRIKETHROUGH_ON);
		}
		// Font color
		if (this.fontColor != null) {
			attributes.put(TextAttribute.FOREGROUND, this.fontColor);
		}
		// Font attributes
		if (!attributes.isEmpty()) {
			font = font.deriveFont(attributes);
		}
		// OK
		component.setFont(font);
	}

	/**
	 * Returns the <code>strikedThrough</code> property.
	 * 
	 * @return <code>strikedThrough</code> property.
	 */
	public boolean isStrikedThrough() {
		return this.strikedThrough;
	}

	/**
	 * Sets the <code>strikedThrough</code> property.
	 * 
	 * @param strikedThrough
	 */
	public void setStrikedThrough(boolean strikedThrough) {
		this.strikedThrough = strikedThrough;
	}

	/**
	 * Checks if is the font must be bold.
	 * 
	 * @return true, if is the font is bold
	 */
	public boolean isBold() {
		return this.bold;
	}

	/**
	 * Sets if the font is bold.
	 * 
	 * @param bold
	 *            true if the font is bold
	 */
	public void setBold(boolean bold) {
		this.bold = bold;
	}

	/**
	 * Checks if is the font must be italic.
	 * 
	 * @return true, if is the font is italic
	 */
	public boolean isItalic() {
		return this.italic;
	}

	/**
	 * Sets if the font is italic.
	 * 
	 * @param italic
	 *            true if the font is italic
	 */
	public void setItalic(boolean italic) {
		this.italic = italic;
	}

	/**
	 * Returns the color for the font
	 * 
	 * @return Color
	 */
	public Color getFontColor() {
		return this.fontColor;
	}

	/**
	 * Sets the color for the font
	 * 
	 * @param fontColor
	 *            Color
	 */
	public void setFontColor(Color fontColor) {
		this.fontColor = fontColor;
	}

}
