package net.sf.doolin.gui.swing;

import java.text.FieldPosition;
import java.text.Format;
import java.text.ParsePosition;

import net.sf.doolin.util.Utils;

import org.springframework.beans.factory.annotation.Required;

/**
 * Completion handler that is based on a bean class name and one of its
 * properties to store the text value
 * 
 * @author Damien Coraboeuf
 * 
 * @param <T>
 *            Type of the item
 */
public class ByClassAndPropertyFormat<T> extends Format {

	private static final long serialVersionUID = 1L;

	private Class<T> beanClass;
	private String propertyName;

	/**
	 * Constructor
	 * 
	 * @param beanClass
	 *            Bean class
	 * @param propertyName
	 *            Name of the bean property that holds the text value
	 */
	public ByClassAndPropertyFormat(Class<T> beanClass, String propertyName) {
		this.beanClass = beanClass;
		this.propertyName = propertyName;
	}

	/**
	 * Default constructor
	 */
	public ByClassAndPropertyFormat() {
	}

	/**
	 * Returns the beanClass
	 * 
	 * @return Class<T>
	 */
	public Class<T> getBeanClass() {
		return this.beanClass;
	}

	/**
	 * Sets the beanClass
	 * 
	 * @param beanClass
	 *            Class<T>
	 */
	@Required
	public void setBeanClass(Class<T> beanClass) {
		this.beanClass = beanClass;
	}

	/**
	 * Returns the propertyName
	 * 
	 * @return String
	 */
	public String getPropertyName() {
		return this.propertyName;
	}

	/**
	 * Sets the propertyName
	 * 
	 * @param propertyName
	 *            String
	 */
	@Required
	public void setPropertyName(String propertyName) {
		this.propertyName = propertyName;
	}

	@Override
	public StringBuffer format(Object obj, StringBuffer toAppendTo,
			FieldPosition pos) {
		if (obj != null) {
			Object propertyValue = Utils.getProperty(obj, this.propertyName);
			toAppendTo.append(propertyValue);
		}
		return toAppendTo;
	}

	@Override
	public Object parseObject(String source, ParsePosition pos) {
		T o = Utils.newInstance(this.beanClass);
		Utils.setProperty(o, this.propertyName, source);
		return o;
	}

}
