package net.sf.doolin.gui.swing;

import java.awt.Component;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Insets;
import java.awt.Polygon;
import java.awt.Shape;
import java.awt.SystemColor;

import javax.swing.border.AbstractBorder;
import javax.swing.border.Border;

/**
 * Border that displays the collapsed state of a panel.
 * 
 * @author Damien Coraboeuf
 * 
 * @see CollapsablePanel
 */
public class CollaspableBorder extends AbstractBorder {

	private static final int XGAP = 6;

	private static final long serialVersionUID = 1L;

	private static final int X = 16;

	private static final int Y = 16;

	private final Border border;

	private boolean collapsed;

	/**
	 * Constructor
	 * 
	 * @param initialBorder
	 *            Base border
	 */
	public CollaspableBorder(Border initialBorder) {
		this.border = initialBorder;
	}

	/**
	 * Checks if the border indicates a collapsed state
	 * 
	 * @return Collapsed state
	 */
	public boolean isCollapsed() {
		return this.collapsed;
	}

	/**
	 * Sets the collapsed state of the border
	 * 
	 * @param collapsed
	 *            Collapsed state
	 */
	public void setCollapsed(boolean collapsed) {
		this.collapsed = collapsed;
	}

	@Override
	public Insets getBorderInsets(Component c) {
		if (this.border != null) {
			return this.border.getBorderInsets(c);
		} else {
			return super.getBorderInsets(c);
		}
	}

	@Override
	public void paintBorder(Component c, Graphics g, int x, int y, int width,
			int height) {
		if (this.border != null) {
			this.border.paintBorder(c, g, x, y, width, height);
		}
		Shape arrow;
		x = width - X - XGAP;
		g.setColor(SystemColor.controlShadow);
		if (this.collapsed) {
			y = y - 2;
			arrow = new Polygon(new int[] { 2 + x, X - 2 + x, X / 2 + x },
					new int[] { Y / 2 + y, Y / 2 + y, Y - 2 + y }, 3);
		} else {
			arrow = new Polygon(new int[] { X / 2 + x, X - 2 + x, X / 2 + x },
					new int[] { 2 + y, Y / 2 + y, Y - 2 + y }, 3);
		}
		((Graphics2D) g).fill(arrow);
	}

}
