package net.sf.doolin.gui.swing;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;

import javax.swing.JComboBox;
import javax.swing.JComponent;

import ca.odell.glazedlists.EventList;
import ca.odell.glazedlists.swing.EventComboBoxModel;

/**
 * {@link IFilePath} implementation based on an editable {@link JComboBox}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ComboFilePath extends AbstractFilePath {

	private final JComboBox field;

	/**
	 * Constructor.
	 * 
	 * @param fileList
	 *            List of paths that will be dynamically updated.
	 */
	public ComboFilePath(EventList<String> fileList) {
		this.field = new JComboBox(new EventComboBoxModel<String>(fileList));
		this.field.setEditable(true);
		this.field.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				String text = getFilePath();
				fireNewPath(text);
			}
		});
	}

	@Override
	public void setEnabled(boolean enabled) {
		this.field.setEnabled(enabled);
	}

	@Override
	public JComponent getComponent() {
		return this.field;
	}

	@Override
	public String getFilePath() {
		return (String) this.field.getSelectedItem();
	}

	@Override
	public void setFile(File file) {
		if (file == null) {
			this.field.setSelectedItem(null);
		} else {
			this.field.setSelectedItem(file.getAbsolutePath());
		}
	}

}
