package net.sf.doolin.gui.swing;

import javax.swing.Icon;

import net.sf.doolin.gui.service.IconService;
import net.sf.doolin.gui.service.IconSize;
import net.sf.doolin.gui.service.icon.DefaultIconService;
import net.sf.doolin.gui.util.GUIStrings;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;

/**
 * This label provider is based on an enumeration.
 */
public class EnumLabelInfoProvider implements LabelInfoProvider {

	private boolean useFullName = false;

	private IconService iconService = new DefaultIconService();

	/**
	 * Gets the icon service used to access icons
	 * 
	 * @return Icon service
	 */
	public IconService getIconService() {
		return this.iconService;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public LabelInfo getLabelIcon(Object item) {
		// Enum
		Enum<?> e = (Enum<?>) item;
		if (e == null) {
			return new LabelInfo(" ");
		}
		// Enum class
		String className = e.getClass().getName();
		if (!this.useFullName) {
			className = StringUtils.substringAfterLast(className, ".");
		}
		// It may happen that the Enum class ends with $...
		className = StringUtils.substringBeforeLast(className, "$");
		// Keys
		String textKey = className + "." + e;
		String iconKey = textKey + ".icon";
		// Text
		String text = GUIStrings.getIfPresent(textKey);
		if (text == null) {
			text = e.toString();
		}
		// Icon
		Icon icon = null;
		String iconId = GUIStrings.getIfPresent(iconKey);
		if (iconId != null) {
			icon = this.iconService.getIcon(iconId, IconSize.SMALL);
		}
		// OK
		return new LabelInfo(text, icon);
	}

	/**
	 * Checks if is use full name.
	 * 
	 * @return true, if is use full name
	 */
	public boolean isUseFullName() {
		return this.useFullName;
	}

	/**
	 * Sets the icon service used to access icons
	 * 
	 * @param iconService
	 *            Icon service
	 */
	@Autowired(required = false)
	public void setIconService(IconService iconService) {
		this.iconService = iconService;
	}

	/**
	 * Sets the use full name.
	 * 
	 * @param useFullName
	 *            the new use full name
	 */
	public void setUseFullName(boolean useFullName) {
		this.useFullName = useFullName;
	}
}
