package net.sf.doolin.gui.swing;

import java.io.File;

import javax.swing.JComponent;

/**
 * Interface used by {@link JFile} to abstract the component that is used to
 * display the selected file path.
 * 
 * @author Damien Coraboeuf
 * 
 */
public interface IFilePath {

	/**
	 * Adds a listener for the path change
	 * 
	 * @param filePathListener
	 *            Listener
	 */
	void addFilePathListener(FilePathListener filePathListener);

	/**
	 * Gets the actual component
	 * 
	 * @return Component
	 */
	JComponent getComponent();

	/**
	 * Gets the current file path
	 * 
	 * @return File path or <code>null</code>
	 */
	String getFilePath();

	/**
	 * Removes a listener for the path change
	 * 
	 * @param filePathListener
	 *            Listener
	 */
	void removeFilePathListener(FilePathListener filePathListener);

	/**
	 * Sets the current file path
	 * 
	 * @param file
	 *            Selected file or <code>null</code>
	 */
	void setFile(File file);

	/**
	 * Enables or disables the file path component
	 * 
	 * @param enabled
	 *            Enabled flag
	 */
	void setEnabled(boolean enabled);

}
