package net.sf.doolin.gui.swing;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Rectangle;

import javax.swing.JPanel;
import javax.swing.Scrollable;
import javax.swing.SwingConstants;

/**
 * {@link JPanel} which is {@linkplain Scrollable scrollable}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ScrollablePanel extends JPanel implements Scrollable {

	private static final long serialVersionUID = 1L;

	private final JPanel content;

	/**
	 * Constructor
	 * 
	 * @param content
	 *            Content to scroll
	 */
	public ScrollablePanel(JPanel content) {
		this.content = content;
		setLayout(new BorderLayout());
		add(content, BorderLayout.CENTER);
	}

	@Override
	public Dimension getPreferredScrollableViewportSize() {
		return this.content.getPreferredSize();
	}

	@Override
	public int getScrollableBlockIncrement(Rectangle visibleRect,
			int orientation, int direction) {
		if (orientation == SwingConstants.HORIZONTAL) {
			return visibleRect.width / 3;
		} else {
			return visibleRect.height / 3;
		}
	}

	@Override
	public boolean getScrollableTracksViewportHeight() {
		return false;
	}

	@Override
	public boolean getScrollableTracksViewportWidth() {
		return true;
	}

	@Override
	public int getScrollableUnitIncrement(Rectangle visibleRect,
			int orientation, int direction) {
		if (orientation == SwingConstants.HORIZONTAL) {
			return visibleRect.width / 10;
		} else {
			return visibleRect.height / 10;
		}
	}

}
