package net.sf.doolin.gui.validation;

import javax.swing.JComponent;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.view.decorator.AbstractGUIViewDecorator;
import net.sf.doolin.gui.view.decorator.DecorationStyle;

/**
 * Abstract implementation for a view decorator that setups the validation on a
 * view.
 * 
 * @author Damien Coraboeuf
 * 
 */
public abstract class AbstractValidationGUIViewDecorator extends
		AbstractGUIViewDecorator implements GUIValidationDecorator {

	/**
	 * Decorates a view with a component that allows the validation.
	 */
	@Override
	public <V> JComponent decorate(GUIView<V> view, JComponent component,
			DecorationStyle decorationStyle) {
		// View validator
		GUIValidator<V> validator = view.getViewDescriptor().getValidator();
		// Validation support
		ActionContext actionContext = view.getActionContext();
		ValidationSupport<V> validationSupport = actionContext
				.getValidationSupport();
		validationSupport.setValidator(validator);
		// Decoration
		if (validator != null) {
			return createValidationComponent(view, component, decorationStyle,
					validationSupport);
		} else {
			// No decoration
			return component;
		}
	}

	/**
	 * Creates a component for the validation.
	 * 
	 * @param <V>
	 *            Type of object for the view
	 * @param view
	 *            View to decorate
	 * @param component
	 *            View component to decorate
	 * @param decorationStyle
	 *            Decoration style
	 * @param validationSupport
	 *            Validation support
	 * @return Decorated component
	 */
	protected abstract <V> JComponent createValidationComponent(
			GUIView<V> view, JComponent component,
			DecorationStyle decorationStyle,
			ValidationSupport<V> validationSupport);

}
