package net.sf.doolin.gui.validation;

import org.apache.commons.lang.StringUtils;

/**
 * Abstract validator.
 * 
 * @param <B>
 *            Type of the bean to validate
 * 
 * @author Damien Coraboeuf
 */
public abstract class AbstractValidator<B> implements GUIValidator<B> {

	private String msgMandatoryKey = ValidationMsgKeys.MSG_MANDATORY;

	/**
	 * {@inheritDoc}.
	 * 
	 * @param model
	 *            the bean
	 * 
	 * @return the validation result
	 */
	@Override
	public GUIValidation validate(B model) {
		// Creates the result
		GUIValidation validation = new GUIValidation();
		// Validation
		validate(validation, model);
		// OK
		return validation;
	}

	/**
	 * Checks if is not null.
	 * 
	 * @param result
	 *            the result
	 * @param value
	 *            the value
	 * @param key
	 *            the key
	 * @param name
	 *            the name
	 */
	protected void isNotNull(GUIValidation result, Object value, Object key,
			Object name) {
		validate(result, value != null, key, this.msgMandatoryKey, name);
	}

	/**
	 * Checks if is not blank.
	 * 
	 * @param result
	 *            the result
	 * @param value
	 *            the value
	 * @param key
	 *            the key
	 * @param name
	 *            the name
	 */
	protected void isNotBlank(GUIValidation result, String value, Object key,
			Object name) {
		validate(result, StringUtils.isNotBlank(value), key,
				this.msgMandatoryKey, name);
	}

	/**
	 * Validate.
	 * 
	 * @param result
	 *            the result
	 * @param test
	 *            the test
	 * @param key
	 *            the key
	 * @param msgKey
	 *            the msg key
	 * @param params
	 *            the params
	 */
	protected void validate(GUIValidation result, boolean test, Object key,
			String msgKey, Object... params) {
		if (!test) {
			GUIValidationMessage message = new GUIValidationMessage(key,
					msgKey, params);
			result.addMessage(message);
		}
	}

	/**
	 * Validate.
	 * 
	 * @param validationResult
	 *            the validation result
	 * @param model
	 *            the model to validate
	 */
	protected abstract void validate(GUIValidation validationResult, B model);

	/**
	 * Gets the msg mandatory key.
	 * 
	 * @return the msg mandatory key
	 */
	public String getMsgMandatoryKey() {
		return this.msgMandatoryKey;
	}

	/**
	 * Sets the msg mandatory key.
	 * 
	 * @param msgMandatoryKey
	 *            the new msg mandatory key
	 */
	public void setMsgMandatoryKey(String msgMandatoryKey) {
		this.msgMandatoryKey = msgMandatoryKey;
	}

}
