package net.sf.doolin.gui.validation.support;

import java.io.File;

import net.sf.doolin.gui.validation.ValidationMsgKeys;

/**
 * Validator that checks if a {@link File} is a directory and exists.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class DirExistsObjectValidator implements ObjectValidator {

	@Override
	public String getMsgKey() {
		return ValidationMsgKeys.MSG_DIR_EXISTS;
	}

	@Override
	public Object[] getParams(String name) {
		return new Object[] { name };
	}

	/**
	 * The {@code value} must be a {@link File}, must be a
	 * {@linkplain File#isDirectory() directory} and must
	 * {@linkplain File#exists() exist}.
	 */
	@Override
	public boolean validate(Object value) {
		if (value instanceof File) {
			File dir = (File) value;
			return (dir.isDirectory() && dir.exists());
		} else {
			return false;
		}
	}

}
