package net.sf.doolin.gui.validation.support;

import java.util.Collection;

import net.sf.doolin.gui.validation.ValidationMsgKeys;

import org.apache.commons.lang.StringUtils;

/**
 * This validator checks that the object is not empty.
 * <p>
 * <ul>
 * <li>For a collection, it checks that it is not
 * {@linkplain Collection#isEmpty() empty}.
 * <li>For a string, it checks it is not blank
 * <li>For any other object, it checks it is not <code>null</code>
 * </ul>
 * 
 * @author Damien Coraboeuf
 * @see StringUtils#isNotBlank(String)
 * @see Collection#isEmpty()
 * 
 */
public class NotEmptyObjectValidator implements ObjectValidator {

	@Override
	public String getMsgKey() {
		return ValidationMsgKeys.MSG_MANDATORY;
	}

	@Override
	public Object[] getParams(String name) {
		return new Object[] { name };
	}

	@Override
	public boolean validate(Object value) {
		if (value instanceof Collection<?>) {
			return !((Collection<?>) value).isEmpty();
		} else if (value instanceof String) {
			return StringUtils.isNotBlank((String) value);
		} else {
			return (value != null);
		}
	}

}
