package net.sf.doolin.gui.view.decorator;

import net.sf.doolin.gui.action.swing.ActionFactory;
import net.sf.doolin.gui.action.swing.DefaultActionFactory;
import net.sf.doolin.gui.service.IconService;
import net.sf.doolin.gui.service.icon.DefaultIconService;

import org.springframework.beans.factory.annotation.Autowired;

/**
 * Abstract view decorator that provides services for actions and icons.
 * 
 * @author Damien Coraboeuf
 * 
 */
public abstract class AbstractGUIViewDecorator implements GUIViewDecorator {

	private IconService iconService = new DefaultIconService();

	private ActionFactory actionFactory = DefaultActionFactory.INSTANCE;

	/**
	 * Gets the icon service.
	 * 
	 * @return the icon service
	 */
	public IconService getIconService() {
		return iconService;
	}

	/**
	 * Sets the icon service.
	 * 
	 * @param iconService
	 *            the new icon service
	 */
	@Autowired(required = false)
	public void setIconService(IconService iconService) {
		this.iconService = iconService;
	}

	/**
	 * Gets the action factory.
	 * 
	 * @return the action factory
	 */
	public ActionFactory getActionFactory() {
		return actionFactory;
	}

	/**
	 * Sets the action factory.
	 * 
	 * @param actionFactory
	 *            the new action factory
	 */
	@Autowired(required = false)
	public void setActionFactory(ActionFactory actionFactory) {
		this.actionFactory = actionFactory;
	}

}
