package net.sf.doolin.gui.window.dialog;

import net.sf.doolin.gui.action.GUIAction;

/**
 * This abstract implementation of {@link DialogActionsFactory} provides methods
 * to create instances of default dialog actions: OK and Cancel.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <B>
 *            Type of bean for the window
 */
public abstract class AbstractDialogActionsFactory<B> implements
		DialogActionsFactory {

	/**
	 * Creates the OK action for a dialog
	 * 
	 * @return Action
	 * @see DialogOKAction
	 */
	protected GUIAction getOKAction() {
		return new DialogOKAction<B>();
	}

	/**
	 * Creates the Cancel action for a dialog
	 * 
	 * @return Action
	 * @see DialogCancelAction
	 */
	protected GUIAction getCancelAction() {
		return new DialogCancelAction<B>();
	}
}
