package net.sf.doolin.gui.window.dialog;

import java.util.List;

import net.sf.doolin.gui.action.GUIAction;
import net.sf.doolin.gui.window.GUIWindow;
import net.sf.doolin.gui.window.GUIWindowFactory;
import net.sf.doolin.gui.window.support.DialogWindowFactory;

import org.springframework.beans.factory.annotation.Required;

/**
 * {@link DialogWindowFactory} that uses a list of actions instead of the
 * default ones.
 * 
 * @author Damien Coraboeuf
 * @see CustomDialogActionsFactory
 */
public class CustomDialogWindowFactory implements GUIWindowFactory {

	private List<GUIAction> dialogActions;

	@Override
	public <B> GUIWindow<B> createWindow() {
		CustomDialogActionsFactory<B> dialogActionsFactory = new CustomDialogActionsFactory<B>(
				CustomDialogWindowFactory.this.dialogActions);
		return new DialogGUIWindow<B>(dialogActionsFactory);
	}

	/**
	 * Sets the list of actions for the dialog
	 * 
	 * @param dialogActions
	 *            Action list
	 */
	@Required
	public void setDialogActions(List<GUIAction> dialogActions) {
		this.dialogActions = dialogActions;
	}
}
