package net.sf.doolin.gui.window.opener;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.window.GUIWindow;
import net.sf.doolin.gui.window.descriptor.GUIWindowDescriptor;

import org.springframework.beans.factory.annotation.Required;

/**
 * Opens a new window.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <C>
 *            Type of data for the window
 */
public class WindowOpener<C> extends AbstractViewOpener<C> {

	private GUIWindowDescriptor<C> windowDescriptor;

	/**
	 * Gets the window descriptor.
	 * 
	 * @return the window descriptor
	 */
	public GUIWindowDescriptor<C> getWindowDescriptor() {
		return this.windowDescriptor;
	}

	@Override
	protected ActionContext openViewInternal(ActionContext actionContext,
			C model) {
		// Looks for an already open window
		GUIWindow<C> window = this.windowDescriptor.getWindow(actionContext
				.getApplication(), model);
		// Not already opened window
		if (window == null) {
			// Creates the window
			window = this.windowDescriptor.createWindow(actionContext
					.getApplication(), model);
		}
		// Displays the window
		window.display();
		// OK
		return window.getActionContext();
	}

	/**
	 * Sets the window descriptor.
	 * 
	 * @param windowDescriptor
	 *            the new window descriptor
	 */
	@Required
	public void setWindowDescriptor(GUIWindowDescriptor<C> windowDescriptor) {
		this.windowDescriptor = windowDescriptor;
	}

}
