package net.sf.doolin.gui.window.support;

import java.awt.Container;
import java.awt.Dialog;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JRootPane;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.swing.SwingUtils;

/**
 * Window implementation based on a {@link JDialog}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class DialogIWindow extends AbstractIWindow<JDialog> {

	/**
	 * Constructor.
	 * 
	 * @param actionContext
	 *            Action context
	 */
	public DialogIWindow(ActionContext actionContext) {
		super(actionContext);
	}

	/**
	 * Creates a {@link JDialog}.
	 * 
	 * @see SwingUtils#createWindow(Class, java.awt.Component)
	 */
	@Override
	protected JDialog buildWindow() {
		JDialog dialog = SwingUtils.createWindow(JDialog.class,
				getActionContext().getComponent());
		dialog.setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
		dialog.setModalityType(Dialog.ModalityType.APPLICATION_MODAL);
		return dialog;
	}

	@Override
	public Container getContentPane() {
		return getWindow().getContentPane();
	}

	public JRootPane getRootPane() {
		return getWindow().getRootPane();
	}

	@Override
	public boolean isModal() {
		return getWindow().isModal();
	}

	@Override
	public void pack() {
		getWindow().pack();
	}

	@Override
	public void setDefaultButton(JButton button) {
		getWindow().getRootPane().setDefaultButton(button);
	}

	@Override
	public void setTitle(String value) {
		getWindow().setTitle(value);
	}

}
