package net.sf.doolin.gui.window.support;

import javax.swing.JComponent;

import net.sf.doolin.bus.support.SubscriberValidator;
import net.sf.doolin.gui.action.support.AbstractActionContext;
import net.sf.doolin.gui.app.GUIApplication;
import net.sf.doolin.gui.validation.ValidationSupport;
import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.window.GUIWindow;

/**
 * Action context for a window
 * 
 * @author Damien Coraboeuf
 * 
 * @param <B>
 *            Type of data for the window
 */
public class WindowActionContext<B> extends AbstractActionContext {

	private static final long serialVersionUID = 1L;

	final GUIWindow<B> window;
	private final SubscriberValidator subscriberValidator;

	/**
	 * Constructor
	 * 
	 * @param window
	 *            The window
	 */
	public WindowActionContext(GUIWindow<B> window) {
		super();
		this.window = window;
		this.subscriberValidator = new SubscriberValidator() {

			@Override
			public String getValidatorDescription() {
				return "Window " + WindowActionContext.this.window.getId();
			}

			@Override
			public boolean isValid() {
				return !WindowActionContext.this.window.isClosed();
			}
		};
	}

	@SuppressWarnings("unchecked")
	@Override
	protected ValidationSupport<B> createValidationSupport() {
		return new WindowValidationSupportImpl<B>(this);
	}

	@Override
	public GUIApplication getApplication() {
		return getWindow().getApplication();
	}

	@Override
	public JComponent getComponent() {
		return this.window.getWindowPanel();
	}

	@Override
	public Object getData() {
		return this.window.getWindowData();
	}

	@Override
	public SubscriberValidator getSubscriberValidator() {
		return this.subscriberValidator;
	}

	@Override
	public <T> GUIView<T> getView() {
		return null;
	}

	@SuppressWarnings("unchecked")
	@Override
	public <T> GUIWindow<T> getWindow() {
		return (GUIWindow<T>) this.window;
	}
}
