package net.sf.doolin.gui.wizard.rule;

import net.sf.doolin.gui.action.GUIAction;

/**
 * Defines the navigation rules for a wizard.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <B>
 *            Type of bean for the wizard
 */
public interface WizardRules<B> {

	/**
	 * Checks if the wizard can be finished in its current status.
	 * 
	 * @param currentViewId
	 *            Current view name
	 * @param model
	 *            Wizard bean
	 * @return <code>true</code> if the wizard can be finished
	 */
	boolean canFinish(String currentViewId, B model);

	/**
	 * Returns the next it is possible to navigate to or <code>null</code> if no
	 * next view is available.
	 * 
	 * @param currentViewId
	 *            Current view name
	 * @param model
	 *            Wizard bean
	 * @return Name of the next view or <code>null</code>
	 */
	String getNext(String currentViewId, B model);

	/**
	 * Gets the transaction action to execute when navigating to the given view.
	 * 
	 * @param viewId
	 *            View to navigate to
	 * @return Action to execute or <code>null</code> if none is to be executed
	 */
	GUIAction getTransitionAction(String viewId);

}
