package net.sf.doolin.gui.wizard.rule.condition;

import net.sf.jstring.LocalizableException;
import org.apache.commons.jexl.Expression;
import org.apache.commons.jexl.ExpressionFactory;
import org.apache.commons.jexl.JexlContext;
import org.apache.commons.jexl.JexlHelper;
import org.springframework.beans.factory.annotation.Required;

/**
 * This rule is based on a JEXL expression.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class JEXLWizardRule extends AbstractWizardRule {

	private static final String JEXLWIZARD_RULE_ERROR = "JEXLWizardRule.error";

	private String condition;
	private String modelName = "model";

	/**
	 * Evaluates the JEXL expression to a boolean.
	 */
	@SuppressWarnings("unchecked")
	@Override
	public boolean evaluate(Object model) {
		try {
			Expression e = ExpressionFactory.createExpression(this.condition);
			JexlContext context = JexlHelper.createContext();
			context.getVars().put(this.modelName, model);
			Object o = e.evaluate(context);
			if (o == null) {
				return false;
			} else if (o instanceof Boolean) {
				return (Boolean) o;
			} else {
				return Boolean.valueOf(o.toString());
			}
		} catch (Exception ex) {
			throw new LocalizableException(JEXLWIZARD_RULE_ERROR, ex, this.condition,
					ex);
		}
	}

	/**
	 * Gets the JEXL expression
	 * 
	 * @return JEXL expression
	 */
	public String getCondition() {
		return this.condition;
	}

	/**
	 * Gets the name of the wizard bean in the JEXL expression
	 * 
	 * @return Bean name
	 */
	public String getModelName() {
		return this.modelName;
	}

	/**
	 * Sets the JEXL expression
	 * 
	 * @param condition
	 *            JEXL expression
	 */
	@Required
	public void setCondition(String condition) {
		this.condition = condition;
	}

	/**
	 * Sets the name of the wizard bean in the JEXL expression. It is set by
	 * default to "model".
	 * 
	 * @param modelName
	 *            Bean name
	 */
	public void setModelName(String modelName) {
		this.modelName = modelName;
	}

}
