package net.sf.doolin.gui.wizard.support;

import net.sf.doolin.gui.action.GUIAction;
import net.sf.doolin.gui.window.dialog.DialogActionsFactory;

/**
 * This abstract factory provides methods to create default wizard actions.
 * 
 * @author Damien Coraboeuf
 * 
 */
public abstract class AbstractWizardActionsFactory implements
		DialogActionsFactory {

	/**
	 * Gets the default "Cancel" actions
	 * 
	 * @return "Cancel" action
	 * @see WizardCancelAction
	 */
	protected GUIAction getCancelAction() {
		return new WizardCancelAction();
	}

	/**
	 * Gets the default "Finish" actions
	 * 
	 * @return "Finish" action
	 * @see WizardFinishAction
	 */
	protected GUIAction getFinishAction() {
		return new WizardFinishAction();
	}

	/**
	 * Gets the default "Next" actions
	 * 
	 * @return "Next" action
	 * @see WizardNextAction
	 */
	protected GUIAction getNextAction() {
		return new WizardNextAction();
	}

	/**
	 * Gets the default "Previous" actions
	 * 
	 * @return "Previous" action
	 * @see WizardPreviousAction
	 */
	protected GUIAction getPreviousAction() {
		return new WizardPreviousAction();
	}

}
