package net.sf.doolin.gui.docking.storage;

import net.sf.doolin.gui.service.GUIPreferences;
import net.sf.doolin.gui.window.GUIWindow;

/**
 * Implementation for {@link Storage} that stores data associated with a window
 * in the {@linkplain GUIPreferences preferences}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class DefaultStorage implements Storage {

	@Override
	public String retrieve(GUIWindow<?> window) {
		// Window ID
		String windowId = window.getId();
		// Preferences
		GUIPreferences preferences = window.getApplication().getPreferences();
		// Preferences key
		String key = String.format("Docking.%s", windowId);
		// Retrieval from preferences
		String value = preferences.getString(key, null);
		// OK
		return value;
	}

	@Override
	public void store(GUIWindow<?> window, String value) {
		// Gets the preferences
		GUIPreferences preferences = window.getApplication().getPreferences();
		// Window id
		String windowId = window.getId();
		// Preferences key
		String key = String.format("Docking.%s", windowId);
		// Saves in preferences
		preferences.setString(key, value);
		// Saves the preferences
		preferences.save();
	}

}
